pub struct BinanceSpotPublicJsonWebSocketClient { /* private fields */ }Expand description
Binance Spot public JSON WebSocket client.
Implementations
Sourceimpl BinanceSpotPublicJsonWebSocketClient
impl BinanceSpotPublicJsonWebSocketClient
Sourcepub fn new(
url: Option<String>,
heartbeat: Option<u64>,
transport_backend: TransportBackend,
) -> Self
pub fn new( url: Option<String>, heartbeat: Option<u64>, transport_backend: TransportBackend, ) -> Self
Creates a new Spot public JSON WebSocket client.
Sourcepub async fn close(&mut self) -> Result<()>
pub async fn close(&mut self) -> Result<()>
Closes all WebSocket connections and tasks.
Errors
Returns an error if command delivery fails while shutting down.
Sourcepub async fn subscribe(&self, streams: Vec<String>) -> Result<()>
pub async fn subscribe(&self, streams: Vec<String>) -> Result<()>
Subscribes to stream names.
Errors
Returns an error if command delivery fails or if the connection pool is exhausted.
Sourcepub fn stream(&self) -> impl Stream<Item = BinanceSpotPublicWsMessage> + 'static
pub fn stream(&self) -> impl Stream<Item = BinanceSpotPublicWsMessage> + 'static
Returns a stream of output messages.
Sourcepub fn cache_instruments(&self, instruments: &[InstrumentAny])
pub fn cache_instruments(&self, instruments: &[InstrumentAny])
Bulk initialize the instrument cache.
Sourcepub fn instruments_cache(&self) -> Arc<AtomicMap<Ustr, InstrumentAny>> ⓘ
pub fn instruments_cache(&self) -> Arc<AtomicMap<Ustr, InstrumentAny>> ⓘ
Returns a shared reference to the instruments cache.